// Set up the dimensions and margins of the graph
const margin = {
    top: 50,
    right: 400,
    bottom: 45,
    left: 75,
  },
  width = 945 - margin.left - margin.right,
  height = 472 - margin.top - margin.bottom;

// Append the SVG object to the body of the page
const svg = d3
  .select('body')
  .append('svg')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    `translate(${margin.left},${margin.top})`,
  );

// Read the data
d3.csv('bubblechart.csv').then((data) => {
  // Add chart title
  svg
    .append('text')
    .attr('x', width / 2)
    .attr('y', -20)
    .attr('text-anchor', 'middle')
    .style('font-size', '22px')
    .text(
      'Correlation Between Processor Speed, RAM, and Storage',
    );

  // Add x axis
  const x = d3
    .scaleLinear()
    .domain([2.3, 3.1]) // Example domain, adjust as needed
    .range([0, width]); // Example range, adjust as needed
  svg
    .append('g')
    .attr('transform', `translate(0, ${height})`)
    .call(d3.axisBottom(x));

  // Add x axis label
  svg
    .append('text')
    .attr('text-anchor', 'middle')
    .attr('x', width / 2)
    .attr('y', height + 40)
    .text('Processor Speed (GHz)');

  // Add y axis
  const y = d3
    .scaleLinear()
    .domain([4, 12]) // Example domain, adjust as needed
    .range([height, 0]); // Example range, adjust as needed
  svg.append('g').call(d3.axisLeft(y));

  // Add y axis label
  svg
    .append('text')
    .attr('text-anchor', 'middle')
    .attr('x', -height / 2)
    .attr('y', -50)
    .text('RAM (GB)')
    .attr('transform', 'rotate(-90)');

  // Add a scale for bubble size
  const z = d3
    .scaleLinear()
    .domain([128, 512]) // Example domain, adjust as needed
    .range([5, 25]); // Example range, adjust as needed

  // Add a scale for bubble color
  const makes = data.map((d) => d.Brand);
  const color = d3
    .scaleOrdinal()
    .domain(makes)
    .range(d3.schemeCategory10);

  // Add circles
  svg
    .selectAll('circle')
    .data(data)
    .enter()
    .append('circle')
    .attr('cx', (d) => x(+d['Processor (GHz)']))
    .attr('cy', (d) => y(+d['RAM (GB)']))
    .attr('r', (d) => z(+d['Storage (GB)']))
    .style('fill', (d) => color(d.Brand))
    .attr('opacity', 0.7);

  // Add legend
  const legend = svg
    .selectAll('.legend')
    .data(color.domain())
    .enter()
    .append('g')
    .attr('class', 'legend')
    .attr('transform', function (d, i) {
      return 'translate(0,' + i * 20 + ')';
    });

  // Draw legend colored rectangles
  legend
    .append('rect')
    .attr('x', width - 18)
    .attr('width', 18)
    .attr('height', 18)
    .style('fill', color);

  // Draw legend text
  legend
    .append('text')
    .attr('x', width - 24)
    .attr('y', 9)
    .attr('dy', '.35em')
    .style('text-anchor', 'end')
    .text(function (d) {
      return d;
    });
});
